Bar

Struct Bar 

pub struct Bar {
Show 14 fields pub open: f64, pub high: f64, pub low: f64, pub close: f64, pub volume: f64, pub index: u64, pub time: i64, pub is_first: bool, pub is_last: bool, pub is_new: bool, pub is_confirmed: bool, pub is_history: bool, pub is_realtime: bool, pub is_last_confirmed_history: bool,
}
Represents a single bar/candle of market data

Fields

open: f64high: f64low: f64close: f64volume: f64index: u64time: i64

The bar’s opening time as a UNIX timestamp in milliseconds, exposed to scripts as the time variable.

is_first: bool

Barstate flags the host supplies, exposed to scripts as barstate.*. The first bar of the dataset (barstate.isfirst).

is_last: bool

The last bar of the dataset (barstate.islast).

is_new: bool

A new bar has just opened (barstate.isnew).

is_confirmed: bool

The bar is closed/confirmed (barstate.isconfirmed).

is_history: bool

A historical bar (barstate.ishistory).

is_realtime: bool

A real-time bar (barstate.isrealtime).

is_last_confirmed_history: bool

The last historical bar before real-time (barstate.islastconfirmedhistory).