pub struct DirLoader { /* private fields */ }Expand description
A LibraryLoader that reads libraries from directories on disk.
Implementations
Sourceimpl DirLoader
impl DirLoader
pub fn new(roots: Vec<PathBuf>) -> Self
Sourcepub fn source_of(&self, path: &str) -> Option<String>
pub fn source_of(&self, path: &str) -> Option<String>
The source of a library this loader already resolved, if any. Keyed by import path — the same string sema attributes its diagnostics to.
Sourcepub fn resolve_path(&self, path: &str) -> Option<PathBuf>
pub fn resolve_path(&self, path: &str) -> Option<PathBuf>
The on-disk file path resolves to, without reading it — for locating a
library file (e.g. editor go-to-definition).